@@ -1,5 +1,18 @@
 /**
  * SieveRules plugin script
+ *
+ * @licstart  The following is the entire license notice for the
+ * JavaScript code in this file.
+ *
+ * Copyright (C) 2009-2014 Philip Weir
+ *
+ * The JavaScript code in this page is free software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, either version 3 of
+ * the License, or (at your option) any later version.
+ *
+ * @licend  The above is the entire license notice
+ * for the JavaScript code in this file.
  */
 
 rcube_webmail.prototype.sieverules_select = function(list) {
@@ -865,6 +878,8 @@ rcube_webmail.prototype.sieverules_toggle_eheadlast = function(obj) {
 }
 
 rcube_webmail.prototype.validate_vacation = function(i, sender, alias, period, subject, msg) {
+	var period_test = new RegExp('^[0-9]+$');
+
 	if (sender.value != '' && sender.value != 'auto' && !rcube_check_email(sender.value.replace(/^\s+/, '').replace(/[\s,;]+$/, ''), true) && !$.isNumeric(sender.value)) {
 		alert(rcmail.gettext('redirectaddresserror','sieverules'));
 		sender.focus();
@@ -883,7 +898,7 @@ rcube_webmail.prototype.validate_vacation = function(i, sender, alias, period, s
 	//	return false;
 	//}
 
-	if (period.value != '' && (!size_test.test(period.value) || period.value < 1)) {
+	if (period.value != '' && (!period_test.test(period.value) || period.value < 1)) {
 		alert(rcmail.gettext('vacperiodwrongformat','sieverules'));
 		period.focus();
 		return false;
@@ -1253,7 +1268,6 @@ $(document).ready(function() {
 					var eheadernames = document.getElementsByName('_eheadname[]');
 					var eheadervals = document.getElementsByName('_eheadval[]');
 					var size_test = new RegExp('^[0-9]+$');
-					var spamtest_test = new RegExp('^[0-9]+$');
 					var header_test = new RegExp('^[a-zA-Z0-9\-]+( ?, ?[a-zA-Z0-9\-]+)*$');
 					var date_test = new RegExp('^[0-9]{4}\-[0-9]{2}\-[0-9]{2}$');
 					var time_test = new RegExp('^[0-9]{2}:[0-9]{2}:[0-9]{2}$');
